@@ -10,6 +10,7 @@
 double update_alpha(arma::vec& alpha_acceptance,
                   const double& alpha_old,
                   const arma::mat& rankings,
+                  const arma::vec& obs_freq,
                   const int& cluster_index,
                   const arma::vec& rho_old,
                   const double& alpha_prop_sd,
@@ -23,7 +24,7 @@ void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
                 int& rho_index, const int& cluster_index, const int& rho_thinning,
                 const double& alpha_old, const int& leap_size, const arma::mat& rankings,
                 const std::string& metric, const int& n_items, const int& t,
-                const arma::uvec& element_indices);
+                const arma::uvec& element_indices, const arma::vec& obs_freq);
 
 arma::mat initialize_rho(Rcpp::Nullable<arma::mat> rho_init, int n_items, int n_clusters);
 
