@@ -40,7 +40,7 @@ double exact_logz(const int& n_items, const double& alpha, const std::string& me
   } else if(metric == "kendall"){
     return kendall_logz(n_items, alpha);
   } else {
-    Rcpp::stop("Partition function not available. Please precompute with estimate_partition_functino().");
+    Rcpp::stop("Partition function not available. Please precompute with estimate_partition_function().");
   }
 }
 
@@ -71,19 +71,53 @@ double logz_cardinalities(const double& alpha, const int& n_items, const arma::v
   }
 }
 
-//' Compute the logarithm of the partition function for a Mallows rank model.
+//' Compute the logarithm of the expected distance of metrics for a Mallows rank model
 //'
 //' @param n_items Number of items.
 //' @param alpha The value of the alpha parameter.
 //' @param cardinalities Number of occurrences for each unique distance.
-//' Applicable for footrule and Spearman distance. Defaults to \code{R_NilValue}.
+//' Applicable for Footrule and Spearman distance.
+//' @param metric A string. Available options are \code{"ulam"}, \code{"footrule"} and \code{"spearman"}.
+//' @return A scalar, the logarithm of the partition function.
+//' @keywords internal
+//'
+// [[Rcpp::export]]
+double log_expected_dist(const double& alpha, const int& n_items,
+                         const arma::vec& cardinalities, const std::string& metric){
+  if(metric == "footrule"){
+    arma::vec distances = arma::regspace(0, 2, std::floor(std::pow(static_cast<double>(n_items), 2.) / 2));
+    return std::log(arma::sum(distances % cardinalities % arma::exp(-alpha * distances / n_items)))
+      -std::log(arma::sum(cardinalities % arma::exp(-alpha * distances / n_items)));
+  } else if (metric == "spearman"){
+    arma::vec distances = arma::regspace(0, 2, 2 * binomial_coefficient(n_items + 1, 3));
+    return std::log(arma::sum(distances % cardinalities % arma::exp(-alpha * distances / n_items)))
+      -std::log(arma::sum(cardinalities % arma::exp(-alpha * distances / n_items)));
+  } else if (metric == "ulam"){
+    arma::vec distances = arma::regspace(0, 1, n_items - 1);
+    return std::log(arma::sum(distances % cardinalities % arma::exp(-alpha * distances / n_items)))
+      -std::log(arma::sum(cardinalities % arma::exp(-alpha * distances / n_items)));
+  } else {
+    Rcpp::stop("Cardinalities not implemented for the provided metric.");
+  }
+}
+
+
+
+//' Compute the logarithm of the partition function for a Mallows rank model
+//'
+//' @param n_items Number of items.
+//' @param alpha The value of the alpha parameter.
+//' @param cardinalities Number of occurrences for each unique distance.
+//' Applicable for Footrule and Spearman distance. Defaults to \code{R_NilValue}.
 //' @param logz_estimate Precomputed importance sampling fit.
 //' @param metric A string. Available options are \code{"footrule"},
-//' \code{"kendall"}, \code{"spearman"}, \code{"cayley"}, and \code{"hamming"}.
+//' \code{"kendall"}, \code{"spearman"}, \code{"cayley"}, \code{"hamming"}, and \code{"ulam"}.
 //' Defaults to \code{"footrule"}.
 //' @return A scalar, the logarithm of the partition function.
 //' @keywords internal
 //'
+//' @references \insertAllCited{}
+//'
 // [[Rcpp::export]]
 double get_partition_function(int n_items, double alpha,
                               const Rcpp::Nullable<arma::vec> cardinalities = R_NilValue,
